==> sdx-2.2.2-src.tar.gz: sdx-2.2.2/src/java/fr/gouv/culture/sdx/search/lucene/analysis/Analyzer.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.search.lucene.analysis;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.logger.LogEnabled;
import org.apache.lucene.analysis.TokenStream;

import java.io.Reader;

/**
 * An analyzers is used in indexing and querying for extracting words.
 */
public interface Analyzer extends LogEnabled, Configurable, java.io.Serializable {

    /** Creates a TokenStream which tokenizes all the text in the provided
     Reader.  Default implementation forwards to tokenStream(Reader) for
     compatibility with older version.  Override to allow Analyzer to choose
     strategy based on document and/or field.  Must be able to handle null
     field name for backward compatibility. */
    TokenStream tokenStream(String fieldName, Reader reader);

    /** Creates a TokenStream which tokenizes all the text in the provided
     *  Reader.  Provided for backward compatibility only.
     * @deprecated use tokenStream(String, Reader) instead.
     * @see #tokenStream(String, java.io.Reader)
     */
    TokenStream tokenStream(Reader reader);
}

==> sdx-2.3-src.tar.gz: sdx-2.3/src/java/fr/gouv/culture/sdx/search/lucene/analysis/Analyzer.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/
package fr.gouv.culture.sdx.search.lucene.analysis;

import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.logger.LogEnabled;
import org.apache.lucene.analysis.TokenStream;
import org.apache.excalibur.xml.sax.XMLizable;

import java.io.Reader;

/**
 * An analyzers is used in indexing and querying for extracting words.
 */
public interface Analyzer extends LogEnabled, Configurable, java.io.Serializable, XMLizable {

    /** Creates a TokenStream which tokenizes all the text in the provided
     Reader.  Default implementation forwards to tokenStream(Reader) for
     compatibility with older version.  Override to allow Analyzer to choose
     strategy based on document and/or field.  Must be able to handle null
     field name for backward compatibility. */
    TokenStream tokenStream(String fieldName, Reader reader);

    /** Creates a TokenStream which tokenizes all the text in the provided
     *  Reader.  Provided for backward compatibility only.
     * @deprecated use tokenStream(String, Reader) instead.
     * @see #tokenStream(String, java.io.Reader)
     */
    TokenStream tokenStream(Reader reader);
}
